@@ -1,6 +1,4 @@
 test_that("is_single_digit_numeric works", {
-  skip_on_cran()
-
   expect_true(is_single_digit_numeric(1234))
   expect_false(is_single_digit_numeric(c(1, 2, 3, 4)))
 })
@@ -14,16 +12,11 @@ test_that("is_sequential works", {
   expect_false(is_sequential())
 })
 
-test_that("sim_info and report works", {
-  skip_on_cran()
-
-  expect_message(sim_info("this is a message"))
+test_that("report works", {
   expect_message(report("this is a message"))
 })
 
 test_that("double_games works", {
-  skip_on_cran()
-
   g <- data.frame(
     sim = 2020,
     game_type = "REG",
